==> dabstick-radio-0.92.tgz: dabstick-radio-0.92/dabreceiver-V2/ofdm/ofdm_processor.h <==
#
#ifndef	OFDM_DECODER
#define	OFDM_DECODER
/*
 *
 */
#include	"dab-constants.h"
#include	"stdint.h"
#include	"phasereference.h"
#include	"ofdm_decoder.h"
#include	"fic_handler.h"
#include	"msc_handler.h"
#include	"virtual_input.h"
#include	<QThread>
#include	<QObject>
#include	"ringbuffer.h"

class	RadioInterface;

#define	NEW_PRS	0100
#define	USE_PRS	0101

class	common_fft;

class ofdm_processor: public QThread {
Q_OBJECT
public:
		ofdm_processor	(virtualInput *,
	                         uint32_t,
	                         uint32_t,
	                         uint32_t,
	                         uint32_t,
	                         RadioInterface *,
	                         mscHandler *,
	                         ficHandler *,
	                         int16_t,		// fillpoint
	                         int16_t,		// repeat frequency
	                         RingBuffer<DSPCOMPLEX> *,
	                         RingBuffer<DSPCOMPLEX> *,	// passing
	                         bool);
		~ofdm_processor	(void);
	void	setOffset	(int32_t);
	void	setGain		(int16_t);
	void	coarseCorrectorOn	(void);
	void	coarseCorrectorOff	(void);
	void	startDumping		(FILE *);
	void	stopDumping		(void);
private:
virtual	void		run		(void);
	void		showSpectrum	(int16_t);
	bool		running;
	int16_t		gain;
	bool		dumping;
	FILE		*dumpFile;
	int16_t		frequency;
	virtualInput	*theRig;
	RingBuffer<DSPCOMPLEX> * scopeBuffer;
	virtualInput	*newRig;
	int32_t		theOffset;
	uint32_t	sampleRate;
	uint32_t	Tnull;
	uint32_t	T_u;
	uint32_t	T_s;
	RadioInterface	*myRadioInterface;
	bool		lightRun;

	int32_t		FreqOffset;
//	Oscillator	*localOscillator;
	DSPCOMPLEX	*oscillatorTable;
	int32_t		localPhase;
	int16_t		fineCorrector;
	int32_t		coarseCorrector;
	float		f2Corrector;
volatile	bool		f2Correction;
	int32_t		frequencyCorrector;
	DSPCOMPLEX	*syncBuffer;
	uint32_t	syncBufferSize;
	uint32_t	syncBufferMask;
	uint32_t	syncBufferIndex;
	DSPFLOAT	syncFilterSum;
	DSPFLOAT	signalLevel;
	DSPFLOAT	nullLevel;
	DSPFLOAT	currLevel;
	uint32_t	initCount;
	int32_t		sampleCount;
	int32_t		dMode;
	uint32_t	syncTries;
	uint32_t	syncCounter;
	int32_t		tokenLength;
	int32_t		tokenCount;
	int32_t		avgTokenLength;
	DSPFLOAT	avgSync;

	int8_t		decoderMode;
	int16_t		*ibits;
	DSPCOMPLEX	*ofdmBuffer;
	uint32_t	ofdmBufferIndex;
	uint32_t	ofdmSymbolCount;
	phaseReference	*phaseSynchronizer;
	uint32_t	syncPhaseIndex;
	ofdm_decoder	*ofdmDecoder;
	DSPFLOAT	FreqCorr ;
	DSPFLOAT	avgCorr;
	ficHandler	*my_ficHandler;
	mscHandler	*my_mscHandler;
	int16_t		fillSize;
signals:
	void		show_fineCorrector	(int);
	void		show_coarseCorrector	(int);
	void		show_avgTokenLength	(int);
	void		showScope		(int);
};
#endif

==> dabstick-radio-0.95.tgz: dabstick-radio-0.95/dabreceiver-V2/ofdm/ofdm_processor.h <==
#
/*
 * 	In order to do some performance testing with various
 * 	coding styles, there are two versions of the ofdm_processor
 * 	One where the "state" is maintained explicitly, i.e. one pushes
 * 	a single sample into the machine, the other where the "state"
 * 	is maintained implicitly, i.e. the running code calls for new
 * 	samples from different places.
 * 	Both are valid implementation, both implementing
 * 	the virtual class ofdm_processor
 */
#
#ifndef	OFDM_DECODER
#define	OFDM_DECODER
/*
 *
 */
#include	"dab-constants.h"
#include	"stdint.h"
#include	"phasereference.h"
#include	"ofdm_decoder.h"
#include	"fic_handler.h"
#include	"msc_handler.h"
#include	"virtual_input.h"
#include	<QThread>
#include	<QObject>
#include	"ringbuffer.h"

class	RadioInterface;
class	common_fft;

class ofdm_processor: public QThread {
Q_OBJECT
public:
		ofdm_processor	(virtualInput *,
	                         uint32_t,
	                         uint32_t,
	                         uint32_t,
	                         RadioInterface *,
	                         mscHandler *,
	                         ficHandler *,
	                         int16_t,		// fillpoint
	                         RingBuffer<DSPCOMPLEX> *,
	                         RingBuffer<DSPCOMPLEX> *,	// passing
	                         int32_t,		// buffersize
	                         bool);
virtual		~ofdm_processor	(void);
	void	setOffset	(int32_t);
	void	setGain		(int16_t);
	void	coarseCorrectorOn	(void);
	void	coarseCorrectorOff	(void);
	void	startDumping	(FILE *);
	void	stopDumping	(void);
	void	showSpectrum	(int16_t);
	bool	running;
	int16_t	gain;
	bool	dumping;
	FILE	*dumpFile;
	int32_t	ibufferSize;
	virtualInput	*theRig;
	RingBuffer<DSPCOMPLEX> * scopeBuffer;
	uint32_t	Tnull;
	uint32_t	T_u;
	uint32_t	T_s;
	RadioInterface	*myRadioInterface;
	bool		lightRun;
	uint8_t		*dataBuffer;
	int32_t		FreqOffset;
	DSPCOMPLEX	*oscillatorTable;
	int32_t		localPhase;
	int16_t		fineCorrector;
	int32_t		coarseCorrector;
	float		f2Corrector;
volatile
	bool		f2Correction;
	int32_t		frequencyCorrector;
	DSPCOMPLEX	*syncBuffer;
	uint32_t	syncBufferSize;
	uint32_t	syncBufferMask;
	uint32_t	syncBufferIndex;
	DSPFLOAT	syncFilterSum;
	DSPFLOAT	signalLevel;
	DSPFLOAT	nullLevel;
	DSPFLOAT	currLevel;
	uint32_t	initCount;
	int32_t		tokenLength;
	int32_t		tokenCount;
	int32_t		avgTokenLength;
	int16_t		*ibits;
	DSPCOMPLEX	*ofdmBuffer;
	uint32_t	ofdmBufferIndex;
	uint32_t	ofdmSymbolCount;
	phaseReference	*phaseSynchronizer;
	ofdm_decoder	*ofdmDecoder;
	DSPFLOAT	FreqCorr;
	DSPFLOAT	avgCorr;
	ficHandler	*my_ficHandler;
	mscHandler	*my_mscHandler;
	int16_t		fillSize;
signals:
	void		show_fineCorrector	(int);
	void		show_coarseCorrector	(int);
	void		show_avgTokenLength	(int);
	void		showScope		(int);
};
#endif
